@@ -1,5 +1,5 @@
 
-DunnetCritic=function(gln,gld,sig){
+DunnetCritic=function(gld,gln,sig){
 
 D0.001=c(31.70911445,39.50204486,44.05741169,47.22292126,49.62479055,51.54744566,53.1428387,54.50127044,55.68062337,56.7201573,57.64769067,58.48363184,59.24338183,59.93883818,60.5793748,61.17250261,61.724328,62.23987885,62.72334167,63.1782372,65.11516556,66.64854524,67.91224282,68.98401679,69.91276957,70.73111913,72.12139827,
          12.95498338,15.37000099,16.79443314,17.79454632,18.55972184,19.17637644,19.69103786,20.13154697,20.51584157,20.8561315,21.16108883,21.4370857,21.68893623,21.9203627,22.13430022,22.33310254,22.51868498,22.69262618,22.85624209,23.01064076,23.67307817,24.20332976,24.64412036,25.02051831,25.34845066,25.63864617,26.13402352,
