@@ -11,7 +11,7 @@
 #'  regression analysis if treatments are quantitative. To compare the
 #'  additional control with the others treatments, the Dunnet test is used. This
 #'  function considers the completely randomized design."
-#' @usage dic.ad(Dados,alfa=0.05,quali=TRUE,verbose=TRUE)
+#' @usage dic.ad(Dados,alfa=0.05,quali=TRUE,verbose=TRUE,plot=2)
 #' @param  Dados Matriz contendo na primeira coluna a identificacao dos
 #'   tratamentos testemunhas (tratamentos comuns deve ter valor zero ou NA). A
 #'   segunda coluna deve ter a identificacao de todos os tratamentos.  A
@@ -21,9 +21,18 @@
 #'   qualitativo, realizando-se o teste de medias. FALSE indica que o fator e
 #'   quantitativo, sendo feita a analise de regressao.
 #'@param  verbose Valor logico (TRUE/FALSE). TRUE apresenta os resultados da analise.
-
+#'@param  plot Valor numerico indicando o grafico desejado para analise dos residuos:
+#'   \itemize{
+#'    \item 1: Residuals vs Fitted
+#'   \item 2:  QQ-plot
+#'    \item 3:  Scale-Location
+#'     \item 4:  Cook's distance
+#'      \item 5: Histogram
+#'      }
 #' @importFrom stats anova lm na.action na.omit pchisq  pf pt ptukey qt qtukey
 #' @importFrom utils combn read.table
+#' @importFrom stats aov bartlett.test residuals shapiro.test
+#' @importFrom graphics hist
 #' @param  alfa valor indicando o nivel de significancia. Deve ser
 #'   obrigatoriamente "0.001", "0.01", "0.05" ou "0.10" (default = 0.05).
 #' @return Retorna a comparacao multipla de medias obtida por varios testes.
@@ -47,7 +56,8 @@
 #' data(Dados2)
 #' dic.ad(Dados = Dados2,alfa = 0.05,quali =FALSE)
 #' @export
-dic.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
+dic.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE,plot=2){
+  pp=plot
   Dados[,1]=as.character(Dados[,1])
   Dados[is.na(Dados[,1]),1]=0
   Dados[,2]=as.character(Dados[,2])
@@ -126,6 +136,24 @@ dic.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
        CV=100 * sqrt(QMR)/mean(DT[, 3])
        if(verbose){print(paste("CV= ",round(CV,4)) )}
 
+       TT=paste(Dados[,1],Dados[,2])
+       m=aov(Dados[,4]~TT)
+
+       if(pp<5){(plot(m,pp))}
+       if(pp==5){(hist(residuals(m)))}
+       if(verbose){print("")}
+       if(verbose){print("Teste de normalidade")}
+       ST=shapiro.test(residuals(m))
+       if(verbose){print(ST)}
+       BT=bartlett.test(residuals(m),TT)
+       if(verbose){print("")}
+       if(verbose){print("Teste de homogeneidade de variancias")}
+       if(verbose){print(BT)}
+
+
+
+
+
          if(verbose){print("")}
            if(verbose){print("Testes")}
                 if(quali==T){
@@ -217,6 +245,24 @@ dic.ad=function (Dados, alfa=0.05,quali=TRUE,verbose=TRUE){
                 if(verbose){print(anova)}
                 CV=100 * sqrt(QMR)/mean(DT[, 3])
                 if(verbose){print(paste("CV= ",round(CV,4)) )}
+
+                TT=paste(Dados[,1],Dados[,2])
+                m=aov(Dados[,4]~TT)
+                if(pp<5){(plot(m,pp))}
+                if(pp==5){(hist(residuals(m)))}
+                if(verbose){print("")}
+                if(verbose){print("Teste de normalidade")}
+                ST=shapiro.test(residuals(m))
+                if(verbose){print(ST)}
+                BT=bartlett.test(residuals(m),TT)
+                if(verbose){print("")}
+                if(verbose){print("Teste de homogeneidade de variancias")}
+                if(verbose){print(BT)}
+
+
+
+
+
                   if(verbose){print("")}
                     if(verbose){print("Testes")}
                 if(quali==T){
